@@ -1,5 +1,5 @@
 from erp_sync.Resources.resource import Resource
-
+from datetime import datetime, timedelta
 
 class Invoices(Resource):
 
@@ -163,8 +163,8 @@ class Invoices(Resource):
                 if "invoice_number" in payload.keys():
                     data.update({"invoice_number": payload.get("invoice_number", "")})
 
-                if "due_date" in payload.keys():
-                    data.update({"due_date": payload.get("due_date", "")})
+                data.update({"due_date": payload.get("due_date", (datetime.now() + timedelta(days=1)).strftime("%Y-%m-%d"))})
+                data.update({"date": payload.get("invoice_date", datetime.now().strftime("%Y-%m-%d"))})
 
                 line_items = payload.get("line_items", [])
 
@@ -263,8 +263,9 @@ class Invoices(Resource):
                         }
                     )
 
-                if "due_date" in payload.keys():
-                    header.update({"DocDueDate": payload.get("due_date", "")})
+                header.update({"PostingDate": payload.get("invoice_date", datetime.now().strftime("%Y-%m-%d"))})
+                header.update({"DocDate": payload.get("invoice_date", datetime.now().strftime("%Y-%m-%d"))})
+                header.update({"DocDueDate": payload.get("due_date", (datetime.now() + timedelta(days=1)).strftime("%Y-%m-%d"))})
 
                 if "reference" in payload.keys():
                     header.update({"Reference": payload.get("reference", "")})
@@ -349,7 +350,9 @@ class Invoices(Resource):
             elif super().get_client_type() == super().XERO:
 
                 invoices = {
-                    "Status": f'{additional_properties.get("Status", "AUTHORISED")}'
+                    "Status": f'{additional_properties.get("Status", "DRAFT")}',
+                    "Date": payload.get("invoice_date", datetime.now().strftime("%Y-%m-%d")),
+                    "DueDate": payload.get("due_date", (datetime.now() + timedelta(days=1)).strftime("%Y-%m-%d"))
                 }
 
                 if "invoice_type" in payload.keys():
@@ -397,9 +400,6 @@ class Invoices(Resource):
                     if "quantity" in line_items[i].keys():
                         line_items[i]["Quantity"] = line_items[i].pop("quantity")
 
-                if "due_date" in payload.keys():
-                    invoices.update({"DueDate": payload.get("due_date", "")})
-
                 if "reference" in payload.keys():
                     invoices.update({"Reference": payload.get("reference", "")})
 
@@ -418,12 +418,14 @@ class Invoices(Resource):
             elif super().get_client_type() == super().ODOO:
                 data.update(
                     {
-                        "partner_id": payload.get("customer_ledger_id", ""),
+                        "partner_id": int(payload.get("customer_ledger_id", 0)),
                         "name": payload.get("invoice_number", ""),
                         "payment_reference": payload.get("reference", ""),
                         "state": additional_properties.get("state", "draft"),
-                        "currency_id": payload.get("currency_id", 0),
-                        "invoice_date_due": payload.get("due_date", ""),
+                        "currency_id": int(payload.get("currency_id", 0)),
+                        "currency_code": payload.get("currency_code", ""),
+                        "invoice_date": payload.get("invoice_date", datetime.now().strftime("%Y-%m-%d")),
+                        "invoice_date_due": payload.get("due_date", (datetime.now() + timedelta(days=1)).strftime("%Y-%m-%d")),
                     }
                 )
 
@@ -438,15 +440,13 @@ class Invoices(Resource):
 
                 for i in range(len(line_items)):
                     if "item_ledger_id" in line_items[i].keys():
-                        line_items[i]["product_id"] = line_items[i].pop(
-                            "item_ledger_id"
-                        )
+                        line_items[i]["product_id"] = int(line_items[i].pop("item_ledger_id"))
                     if "quantity" in line_items[i].keys():
-                        line_items[i]["quantity"] = line_items[i].pop("quantity")
+                        line_items[i]["quantity"] = int(line_items[i].pop("quantity"))
                     if "price" in line_items[i].keys():
-                        line_items[i]["price_unit"] = line_items[i].pop("price")
+                        line_items[i]["price_unit"] = int(line_items[i].pop("price"))
                     if "tax_id" in line_items[i].keys():
-                        line_items[i]["tax_ids"] = [line_items[i].pop("tax_id")]
+                        line_items[i]["tax_ids"] = [int(line_items[i].pop("tax_id"))]
 
                     if "description" in line_items[i].keys():
                         line_items[i].pop("description")
@@ -463,7 +463,8 @@ class Invoices(Resource):
             elif super().get_client_type() == super().MS_DYNAMICS:
                 data.pop("type")
                 data.update({
-                    "customerNumber": f'{payload.get("customer_ledger_id", "")}'
+                    "customerNumber": f'{payload.get("customer_ledger_id", "")}',
+                    "due_date": f'{payload.get("due_date", (datetime.now() + timedelta(days=1)).strftime("%Y-%m-%d"))}',
                 })
 
                 line_items = payload.get("line_items", [])
