@@ -109,7 +109,7 @@ class Payments(Resource):
 
                 if 'amount' in payload.keys():
                     data.update({
-                        "TotalAmt": payload.get("amount", "")
+                        "TotalAmt": int(payload.get("amount", 0))
                     })
 
                 if 'customer_id' in payload.keys():
@@ -133,14 +133,27 @@ class Payments(Resource):
                 #         }
                 #     })
 
-                if 'reference' in payload.keys():
-                    data.update({
-                        "PaymentRefNum": payload.get("reference", "")
-                    })
+                # if 'reference' in payload.keys():
+                #     data.update({
+                #         "PaymentRefNum": payload.get("reference", "")
+                #     })
                 
                 invoices = payload.get("invoice_payments", [])
 
-                for i in range(len(invoices)):
+                for i in range(len(invoices)): 
+                    if i == 0:
+                        if 'reference' in invoices[i].keys():
+                            data.update({
+                                "PaymentRefNum": invoices[i].pop('reference')
+                            })
+                    
+                    if 'payment_date' in invoices[i].keys():
+                        invoices[i].pop('payment_date')
+                    if 'payment_type' in invoices[i].keys():
+                        invoices[i].pop('payment_type')
+                    if 'account_id' in invoices[i].keys():
+                        invoices[i].pop('account_id')
+
                     invoice = {}
                     if 'amount' in invoices[i].keys():
                         invoice.update({
@@ -179,13 +192,13 @@ class Payments(Resource):
 
                 if 'amount' in payload.keys():
                     payment.update({
-                        "amount": f'{payload.get("amount", "0")}'
+                        "amount": payload.get("amount", "0")
                     })
 
-                if 'reference' in payload.keys():
-                    payment.update({
-                        "reference_number": payload.get("reference", "")
-                    })
+                # if 'reference' in payload.keys():
+                #     payment.update({
+                #         "reference_number": payload.get("reference", "")
+                #     })
 
                 if 'description' in payload.keys():
                     payment.update({
@@ -199,18 +212,25 @@ class Payments(Resource):
 
                 invoices = payload.get("invoice_payments", [])
 
-                for i in range(len(invoices)):
+                for i in range(len(invoices)): 
+                    if i == 0:
+                        if 'reference' in invoices[i].keys():
+                            payment.update({
+                                "reference_number": invoices[i].pop('reference')
+                            })
                     if 'invoice_id' in invoices[i].keys():
                         invoices[i]['invoice_id'] = invoices[i].pop(
                             'invoice_id')
                     if 'amount' in invoices[i].keys():
                         invoices[i]['amount_applied'] = invoices[i].pop(
                             'amount')
-                    
-                    invoices[i].pop('payment_date')
-                    invoices[i].pop('payment_reference')
-                    invoices[i].pop('payment_type')
-                    invoices[i].pop('account_id')
+                            
+                    if 'payment_date' in invoices[i].keys():
+                        invoices[i].pop('payment_date')
+                    if 'payment_type' in invoices[i].keys():
+                        invoices[i].pop('payment_type')
+                    if 'account_id' in invoices[i].keys():
+                        invoices[i].pop('account_id')
                 # if invoices has data in it
                 if bool(invoices):
                     payment.update({
@@ -226,9 +246,10 @@ class Payments(Resource):
             elif super().get_client_type() == super().SAP:
                 header = {}
 
-                header.update({
-                    "Type": data.get("type", "")
-                })
+                if 'type' in data.keys():
+                    header.update({
+                        "Type": data.pop("type")
+                    })                
 
                 if 'date' in payload.keys():
                     header.update({
@@ -283,13 +304,12 @@ class Payments(Resource):
                 invoice_payments = payload.get("invoice_payments", [])
 
                 for i in range(len(invoice_payments)):
-                    invoice_payments[i].pop('invoice_id')
                     if 'payment_date' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentDate'] = invoice_payments[i].pop(
                             'payment_date')
-                    if 'payment_reference' in invoice_payments[i].keys():
+                    if 'reference' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentReference'] = invoice_payments[i].pop(
-                            'payment_reference')
+                            'reference')
                     if 'payment_type' in invoice_payments[i].keys():
                         invoice_payments[i]['PaymentType'] = invoice_payments[i].pop(
                             'payment_type')
@@ -298,6 +318,9 @@ class Payments(Resource):
                             'account_id')
                     if 'amount' in invoice_payments[i].keys():
                         invoice_payments[i]['Amount'] = int(invoice_payments[i].pop('amount'))
+                    
+                    if 'invoice_id' in invoice_payments[i].keys():
+                        invoice_payments[i].pop('invoice_id')
 
                 # if invoice_payments has data in it
                 if bool(invoice_payments):
@@ -323,32 +346,51 @@ class Payments(Resource):
                         "Date": payload.get("date", "")
                     })
 
-                if 'amount' in payload.keys():
-                    payment.update({
-                        "Amount": int(payload.get("amount", 0))
-                    })
+                # if 'amount' in payload.keys():
+                #     payment.update({
+                #         "Amount": int(payload.get("amount", 0))
+                #     })
 
-                if 'reference' in payload.keys():
-                    payment.update({
-                        "Reference": payload.get("reference", "")
-                    })
+                # if 'reference' in payload.keys():
+                #     payment.update({
+                #         "Reference": payload.get("reference", "")
+                #     })
 
-                if 'account_id' in payload.keys():
-                    payment.update({
-                        "Account": {
-                            "AccountID": payload.get("account_id", "")
-                        }
-                    })
+                # if 'account_id' in payload.keys():
+                #     payment.update({
+                #         "Account": {
+                #             "AccountID": payload.get("account_id", "")
+                #         }
+                #     })
                 
                 invoice = payload.get("invoice_payments", [])
 
                 if bool(invoice):
+                    if "account_id" in invoice[0].keys():
+                        payment.update({
+                            "Account": {
+                                "AccountID": f'{invoice[0].pop("account_id")}',
+                            }
+                        })
                     if "invoice_id" in invoice[0].keys():
                         payment.update({
                             "Invoice": {
-                                "InvoiceID": f'{invoice[0].pop("invoice_id")}',
+                                "InvoiceID": invoice[0].pop("invoice_id"),
                             }
                         }) 
+                    if 'amount' in invoice[0].keys():
+                        payment.update({
+                            "Amount": int(invoice[0].pop('amount'))
+                        })
+                    if 'reference' in invoice[0].keys():
+                        payment.update({
+                            "Reference": invoice[0].pop('reference')
+                        }) 
+                    
+                    if 'payment_date' in invoice[0].keys():
+                        invoice[0].pop('payment_date')
+                    if 'payment_type' in invoice[0].keys():
+                        invoice[0].pop('payment_type')
 
                 if bool(payment):
                     data.update({
@@ -362,21 +404,27 @@ class Payments(Resource):
                     "date": payload.get("date", ""),
                     "amount": int(payload.get("amount", 0)),
                     "partner_id": int(payload.get("customer_id", 0)),
-                    "payment_reference": payload.get("reference", ""),
+                    # "payment_reference": payload.get("reference", ""),
                 }
 
                 invoices = payload.get("invoice_payments", [])
 
-                for i in range(len(invoices)):
+                for i in range(len(invoices)):                    
+                    if i == 0:
+                        if 'reference' in invoices[i].keys():
+                            data['payment_reference'] = invoices[i].pop('reference')
+
                     if "invoice_id" in invoices[i].keys():
                         invoices[i]["invoice_id"] = invoices[i].pop("invoice_id")
                     if "amount" in invoices[i].keys():
                         invoices[i]["amount"] = int(invoices[i].pop("amount"))
-                    
-                    invoices[i].pop("payment_date")
-                    invoices[i].pop("payment_reference")
-                    invoices[i].pop("payment_type")
-                    invoices[i].pop("account_id")
+
+                    if 'payment_date' in invoices[i].keys():
+                        invoices[i].pop('payment_date')
+                    if 'payment_type' in invoices[i].keys():
+                        invoices[i].pop('payment_type')
+                    if 'account_id' in invoices[i].keys():
+                        invoices[i].pop('account_id')
 
                 # if line_items has data in it
                 if bool(invoices):
@@ -386,14 +434,36 @@ class Payments(Resource):
             elif super().get_client_type() == super().MS_DYNAMICS:
                 data.pop("type")
                 data.update({
-                    "paymentReference": payload.get("reference", ""),
+                    # "paymentReference": payload.get("reference", ""),
                     "ownerInvoiceType": "Customer",
-                    "ownerInvoiceNumber": f'{payload.get("invoice_id", "")}',
+                    # "ownerInvoiceNumber": f'{payload.get("invoice_id", "")}',
                     "ownerNumber": payload.get("customer_id", ""),
                     "description": payload.get("description", ""),
-                    "amount": payload.get("amount", 0),
+                    # "amount": payload.get("amount", 0),
                     "bankCode": payload.get("bank_code", ""),
                 })
+                invoice = payload.get("invoice_payments", [])
+
+                if bool(invoice):
+                    if "invoice_id" in invoice[0].keys():
+                        data.update({
+                            "ownerInvoiceNumber": invoice[0].pop("invoice_id"),
+                        }) 
+                    if 'reference' in invoice[0].keys():
+                        data.update({
+                            "paymentReference": invoice[0].pop('reference')
+                        })
+                    if 'amount' in invoice[0].keys():
+                        data.update({
+                            "amount": invoice[0].pop('amount')
+                        })                    
+                    
+                    if 'payment_date' in invoice[0].keys():
+                        invoice[0].pop('payment_date')
+                    if 'payment_type' in invoice[0].keys():
+                        invoice[0].pop('payment_type')
+                    if 'account_id' in invoice[0].keys():
+                        invoice[0].pop('account_id')
 
             data.update(additional_properties)
 
